<!DOCTYPE TS><TS>
<context>
    <name>String::DayOfWeek</name>
    <message>
        <source>MON</source>
        <translation>MO</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation>DI</translation>
    </message>
    <message>
        <source>WED</source>
        <translation>MI</translation>
    </message>
    <message>
        <source>THU</source>
        <translation>DO</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation>FR</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation>SA</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation>SO</translation>
    </message>
</context>
<context>
    <name>String::WeatherType</name>
    <message>
        <source>Cloudy</source>
        <translation>bewölkt</translation>
    </message>
    <message>
        <source>Mostly Cloudy</source>
        <translation>meist bewölkt</translation>
    </message>
    <message>
        <source>Partly Cloudy</source>
        <translation>teilw. bewölkt</translation>
    </message>
    <message>
        <source>Light Rain</source>
        <translation>etwas Regen</translation>
    </message>
    <message>
        <source>Showers</source>
        <translation>Schauer</translation>
    </message>
    <message>
        <source>Rain</source>
        <translation>Regen</translation>
    </message>
    <message>
        <source>AM Showers</source>
        <translation>Vorm. Schauer</translation>
    </message>
    <message>
        <source>Fog</source>
        <translation>Nebel</translation>
    </message>
    <message>
        <source>Few Showers</source>
        <translation>vereinzelte Schauer</translation>
    </message>
    <message>
        <source>Mostly Sunny</source>
        <translation>meist sonnig</translation>
    </message>
    <message>
        <source>Sunny</source>
        <translation>sonnig</translation>
    </message>
    <message>
        <source>Scattered Flurries</source>
        <translation>Böen aus wechselnder Richtung</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun</source>
        <translation>Vorm. Wolken, nachm. Sonne</translation>
    </message>
    <message>
        <source>Isolated T-Storms</source>
        <translation>vereinzelte Gewitter</translation>
    </message>
    <message>
        <source>Scattered Thunderstorms</source>
        <translation>verteilte Gewitter</translation>
    </message>
    <message>
        <source>PM Showers</source>
        <translation>Nachm. Schauer</translation>
    </message>
    <message>
        <source>PM Showers/Wind</source>
        <translation>Nachm. Schauer/Wind</translation>
    </message>
    <message>
        <source>Rain/Snow Showers</source>
        <translation>Regen/Schneeschauer</translation>
    </message>
    <message>
        <source>Few Snow Showers</source>
        <translation>vereinzelte Schneeschauer</translation>
    </message>
    <message>
        <source>Cloudy/Wind</source>
        <translation>bewölkt/windig</translation>
    </message>
    <message>
        <source>Flurries/Wind</source>
        <translation>böeig/windig</translation>
    </message>
    <message>
        <source>Mostly Cloudy/Windy</source>
        <translation>meist bewölkt/windig</translation>
    </message>
    <message>
        <source>Rain/Thunder</source>
        <translation>Regen/Gewitter</translation>
    </message>
    <message>
        <source>Partly Cloudy/Windy</source>
        <translation>teilw. bewölkt/windig</translation>
    </message>
    <message>
        <source>AM Rain/Snow Showers</source>
        <translation>Vorm. Regen/Schneeschauer</translation>
    </message>
    <message>
        <source>Light Rain/Wind</source>
        <translation>leichter Regen/Wind</translation>
    </message>
    <message>
        <source>Showers/Wind</source>
        <translation>Schauer/Wind</translation>
    </message>
    <message>
        <source>Mostly Sunny/Wind</source>
        <translation>meist sonnig/Wind</translation>
    </message>
    <message>
        <source>Flurries</source>
        <translation>Böen</translation>
    </message>
    <message>
        <source>Rain/Wind</source>
        <translation>Regen/Wind</translation>
    </message>
    <message>
        <source>Sct Flurries/Wind</source>
        <translation>verteilte, böeige Winde</translation>
    </message>
    <message>
        <source>Sct Strong Storms</source>
        <translation>verteilte, heftige Stürme</translation>
    </message>
    <message>
        <source>PM T-Storms</source>
        <translation>Nachm. Gewitter</translation>
    </message>
    <message>
        <source>Thunderstorms</source>
        <translation>Gewitter</translation>
    </message>
    <message>
        <source>Sunny/Windy</source>
        <translation>sonnig/windig</translation>
    </message>
    <message>
        <source>AM Thunderstorms</source>
        <translation>Vorm. Gewitter</translation>
    </message>
    <message>
        <source>AM Rain</source>
        <translation>Vorm. Regen</translation>
    </message>
    <message>
        <source>Iso T-Storms/Wind</source>
        <translation>vereinzelte Gewitter/Wind</translation>
    </message>
    <message>
        <source>Rain/Snow</source>
        <translation>Regen/Schnee</translation>
    </message>
    <message>
        <source>Sct T-Storms/Wind</source>
        <translation>verteilte Gewitter/Wind</translation>
    </message>
    <message>
        <source>AM Showers/Wind</source>
        <translation>Vorm. Schauer/Wind</translation>
    </message>
    <message>
        <source>Sct Snow Showers</source>
        <translation>verteilte Schneeschauer</translation>
    </message>
    <message>
        <source>Snow to Ice/Wind</source>
        <translation>Schnee in Hagel überg./Wind</translation>
    </message>
    <message>
        <source>Snow to Rain</source>
        <translation>Schnee in Regen überg.</translation>
    </message>
    <message>
        <source>AM Light Rain</source>
        <translation>Vorm. etwas Regen</translation>
    </message>
    <message>
        <source>PM Light Rain</source>
        <translation>Nachm. etwas Regen</translation>
    </message>
    <message>
        <source>PM Rain</source>
        <translation>Nachm. Regen</translation>
    </message>
    <message>
        <source>Snow Showers</source>
        <translation>Schneeschauer</translation>
    </message>
    <message>
        <source>Rain to Snow</source>
        <translation>Regen in Schnee überg.</translation>
    </message>
    <message>
        <source>PM Rain/Snow</source>
        <translation>Nachm. Regen/Schnee</translation>
    </message>
    <message>
        <source>Few Showers/Wind</source>
        <translation>wenige Schauer/Wind</translation>
    </message>
    <message>
        <source>Snow/Wind</source>
        <translation>Schnee/Wind</translation>
    </message>
    <message>
        <source>PM Rain/Snow Showers</source>
        <translation>Nachm. Regen/Schneeschauer</translation>
    </message>
    <message>
        <source>PM Rain/Snow/Wind</source>
        <translation>Nachm. Regen/Schnee/Wind</translation>
    </message>
    <message>
        <source>Rain/Snow Showers/Wind</source>
        <translation>Regen/Schneeschauer/Wind</translation>
    </message>
    <message>
        <source>Rain/Snow/Wind</source>
        <translation>Regen/Schnee/Wind</translation>
    </message>
    <message>
        <source>Light Snow</source>
        <translation>etwas Schnee</translation>
    </message>
    <message>
        <source>PM Snow</source>
        <translation>Nachm. Schnee</translation>
    </message>
    <message>
        <source>Few Snow Showers/Wind</source>
        <translation>wenige Schneeschauer/Wind</translation>
    </message>
    <message>
        <source>Light Snow/Wind</source>
        <translation>etwas Schnee/Wind</translation>
    </message>
    <message>
        <source>Wintry Mix</source>
        <translation>Winter-Mix</translation>
    </message>
    <message>
        <source>AM Wintry Mix</source>
        <translation>Vorm. Winter-Mix</translation>
    </message>
    <message>
        <source>Hvy Rain/Freezing Rain</source>
        <translation>heftiger/gefr. Regen</translation>
    </message>
    <message>
        <source>AM Light Snow</source>
        <translation>Vorm. etwas Schnee</translation>
    </message>
    <message>
        <source>Rain/Freezing Rain</source>
        <translation>Regen/gefr. Regen</translation>
    </message>
    <message>
        <source>T-Storms/Wind</source>
        <translation>Gewitter/Wind</translation>
    </message>
    <message>
        <source>Sprinkles</source>
        <translation>Graupel</translation>
    </message>
    <message>
        <source>AM Snow Showers</source>
        <translation>Vorm. Schneeschauer</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun/Wind</source>
        <translation>Vorm. Wolken/Nachm. Sonne/Wind</translation>
    </message>
    <message>
        <source>AM Rain/Snow/Wind</source>
        <translation>Vorm. Regen/Schnee/Wind</translation>
    </message>
    <message>
        <source>Rain to Snow/Wind</source>
        <translation>Regen in Schnee überg./Wind</translation>
    </message>
    <message>
        <source>Snow to Wintry Mix</source>
        <translation>Schnee in Winter-Mix überg.</translation>
    </message>
    <message>
        <source>PM Snow Showers/Wind</source>
        <translation>Nachm. Schneeschauer/Wind</translation>
    </message>
    <message>
        <source>Snow and Ice to Rain</source>
        <translation>Schnee und Hagel in Regen überg.</translation>
    </message>
    <message>
        <source>Heavy Rain</source>
        <translation>heftiger Regen</translation>
    </message>
    <message>
        <source>AM Rain/Ice</source>
        <translation>Vorm. Regen/Hagel</translation>
    </message>
    <message>
        <source>AM Snow Showers/Wind</source>
        <translation>Vorm. Schneeschauer/Wind</translation>
    </message>
    <message>
        <source>AM Light Snow/Wind</source>
        <translation>Vorm. etwas Schnee/Wind</translation>
    </message>
    <message>
        <source>PM Light Rain/Wind</source>
        <translation>Nachm. etwas Regen/Wind</translation>
    </message>
    <message>
        <source>AM Light Wintry Mix</source>
        <translation>Vorm. leichter Winter-Mix</translation>
    </message>
    <message>
        <source>PM Light Snow/Wind</source>
        <translation>Nachm. etwas Schnee/Wind</translation>
    </message>
    <message>
        <source>Heavy Rain/Wind</source>
        <translation>heftiger Regen/Wind</translation>
    </message>
    <message>
        <source>PM Snow Shower</source>
        <translation>Nachm. Schneeschauer</translation>
    </message>
    <message>
        <source>Snow to Rain/Wind</source>
        <translation>Schnee in Regen überg./Wind</translation>
    </message>
    <message>
        <source>PM Light Rain/Ice</source>
        <translation>Nachm. leichter Regen/Hagel</translation>
    </message>
    <message>
        <source>AM Snow</source>
        <translation>Vorm. Schnee</translation>
    </message>
    <message>
        <source>Snow to Ice</source>
        <translation>Schnee in Hagel überg.</translation>
    </message>
    <message>
        <source>Wintry Mix/Wind</source>
        <translation>Winter-Mix/Wind</translation>
    </message>
    <message>
        <source>PM Light Snow</source>
        <translation>Nachm. etwas Schnee</translation>
    </message>
    <message>
        <source>AM Drizzle</source>
        <translation>Vorm. Nieselregen</translation>
    </message>
    <message>
        <source>Strong Storms/Wind</source>
        <translation>starke Stürme/Wind</translation>
    </message>
    <message>
        <source>PM Drizzle</source>
        <translation>Nachm. Nieselregen</translation>
    </message>
    <message>
        <source>Drizzle</source>
        <translation>Nieselregen</translation>
    </message>
    <message>
        <source>AM Light Rain/Wind</source>
        <translation>Vorm. etwas Regen/Wind</translation>
    </message>
    <message>
        <source>AM Rain/Wind</source>
        <translation>Vorm. Regen/Wind</translation>
    </message>
    <message>
        <source>Wintry Mix to Snow</source>
        <translation>Winter-Mix in Schnee überg.</translation>
    </message>
    <message>
        <source>Snow Showers/Windy</source>
        <translation>Schneeschauer/Wind</translation>
    </message>
    <message>
        <source>Light Rain Shower</source>
        <translation>leichte Regenschauer</translation>
    </message>
    <message>
        <source>Light Rain with Thunder</source>
        <translation>etwas Regen mit Donner</translation>
    </message>
    <message>
        <source>Light Drizzle</source>
        <translation>leichter Nieselregen</translation>
    </message>
    <message>
        <source>Mist</source>
        <translation>Nebel</translation>
    </message>
    <message>
        <source>Smoke</source>
        <translation>Rauch</translation>
    </message>
    <message>
        <source>Haze</source>
        <translation>Dunst</translation>
    </message>
    <message>
        <source>Light Snow Shower</source>
        <translation>leichte Schneeschauer</translation>
    </message>
    <message>
        <source>Light Snow Shower/ Windy</source>
        <translation>leichte Schneeschauer/Wind</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Klar</translation>
    </message>
    <message>
        <source>A Few Clouds</source>
        <translation>wenige Wolken</translation>
    </message>
    <message>
        <source>Fair</source>
        <translation>Freundlich</translation>
    </message>
</context>
<context>
    <name>String::WindDirection</name>
    <message>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <source>NNE</source>
        <translation>NNO</translation>
    </message>
    <message>
        <source>NE</source>
        <translation>NO</translation>
    </message>
    <message>
        <source>E</source>
        <translation>O</translation>
    </message>
    <message>
        <source>SE</source>
        <translation>SO</translation>
    </message>
    <message>
        <source>SSE</source>
        <translation>SSO</translation>
    </message>
    <message>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <source>SSW</source>
        <translation>SSW</translation>
    </message>
    <message>
        <source>SW</source>
        <translation>SW</translation>
    </message>
    <message>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <source>NW</source>
        <translation>NW</translation>
    </message>
    <message>
        <source>NNW</source>
        <translation>NNW</translation>
    </message>
    <message>
        <source>ENE</source>
        <translation>ONO</translation>
    </message>
    <message>
        <source>ESE</source>
        <translation>OSO</translation>
    </message>
    <message>
        <source>WSW</source>
        <translation>WSW</translation>
    </message>
    <message>
        <source>WNW</source>
        <translation>WNW</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>loading...</source>
        <translation>Lade...</translation>
    </message>
    <message>
        <source>[ retrieving weather data ... ]</source>
        <translation>[ hole Wetterdaten... ]</translation>
    </message>
    <message>
        <source>current conditions</source>
        <translation>Das aktuelle Wetter</translation>
    </message>
    <message>
        <source>Humidity</source>
        <translation>Luftfeuchtigkeit</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Luftdruck</translation>
    </message>
    <message>
        <source>Wind</source>
        <translation>Windgeschw.</translation>
    </message>
    <message>
        <source>Visibility</source>
        <translation>Sichtweite</translation>
    </message>
    <message>
        <source>Wind Chill</source>
        <translation>Gefühlte Temperatur</translation>
    </message>
    <message>
        <source>UV Index</source>
        <translation>UV Strahlung</translation>
    </message>
    <message>
        <source>extended forecast</source>
        <translation>Weitere Vorhersage</translation>
    </message>
    <message>
        <source>LO</source>
        <translation>Min</translation>
    </message>
    <message>
        <source>HI</source>
        <translation>Max</translation>
    </message>
    <message>
        <source>today&apos;s forecast</source>
        <translation>Vorhersage für Heute</translation>
    </message>
    <message>
        <source>tomorrow&apos;s outlook</source>
        <translation>Vorhersage für Morgen</translation>
    </message>
    <message>
        <source>Forecast for</source>
        <translation>Vorhersage für</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation>Dopplerradar</translation>
    </message>
    <message>
        <source>Map Unavailable</source>
        <translation>Karte nicht verfügbar</translation>
    </message>
    <message>
        <source>RAIN</source>
        <translation>REGEN</translation>
    </message>
    <message>
        <source>MIX/ICE</source>
        <translation>MIX/EIS</translation>
    </message>
    <message>
        <source>SNOW</source>
        <translation>SCHNEE</translation>
    </message>
    <message>
        <source>LIGHT</source>
        <translation>LEICHT</translation>
    </message>
    <message>
        <source>HEAVY</source>
        <translation>KRÄFTIG</translation>
    </message>
    <message>
        <source>Enter Zip Code</source>
        <translation>Postleitzahl eingeben</translation>
    </message>
    <message>
        <source>weather setup</source>
        <translation>Wetter Einstellungen</translation>
    </message>
    <message>
        <source>To save, press &apos;i&apos; - to cancel, hit escape</source>
        <translation>Mit &apos;i&apos; speichern; ESCAPE um abzubrechen</translation>
    </message>
    <message>
        <source>COLD</source>
        <translation>kalt</translation>
    </message>
    <message>
        <source>COLDEST</source>
        <translation>am kältesten</translation>
    </message>
    <message>
        <source>CLOUD TEMPERATURE</source>
        <translation>Wolkentemperatur</translation>
    </message>
</context>
<context>
    <name>Weather</name>
    <message>
        <source> is invalid)</source>
        <translation type="obsolete"> ist ungültig)</translation>
    </message>
    <message>
        <source>   No Location Set, Please read the README</source>
        <translation type="obsolete">   Kein Ort eingestellt, bitte README lesen</translation>
    </message>
    <message>
        <source>Configuring MythWeather...</source>
        <translation type="obsolete">Konfiguriere MythWeather...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select unit conversion...</source>
        <translation type="obsolete">Mit Pfeil-Rechts das Maßsystem wählen...</translation>
    </message>
    <message>
        <source>Weather Units</source>
        <translation type="obsolete">Maßsystem</translation>
    </message>
    <message>
        <source>Location</source>
        <translation type="obsolete">Ort</translation>
    </message>
    <message>
        <source>Aggressiveness</source>
        <translation type="obsolete">Agressivität</translation>
    </message>
    <message>
        <source>Configuration Saved...</source>
        <translation type="obsolete">Konfiguration gespeichert...</translation>
    </message>
    <message>
        <source>Retrieving weather data...</source>
        <translation type="obsolete">Empfange Wetterdaten...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select your location...</source>
        <translation type="obsolete">Mit Pfeil-Rechts den Ort auswählen...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select the aggressiveness level...</source>
        <translation type="obsolete">Mit Pfeil-Rechts die Agressivitätsstufe wählen...</translation>
    </message>
    <message>
        <source> 1  High Speed Connection</source>
        <translation type="obsolete"> 1  schnelle Verbindung</translation>
    </message>
    <message>
        <source> 8  Medium Speed Connection</source>
        <translation type="obsolete"> 8  mittlere Verbindung</translation>
    </message>
    <message>
        <source> 15 Low Speed Connection</source>
        <translation type="obsolete"> 15 langsame Verbindung</translation>
    </message>
    <message>
        <source>Obtaining initial weather data...</source>
        <translation type="obsolete">Hole anfängliche Wetterdaten...</translation>
    </message>
    <message>
        <source>Updating weather data...</source>
        <translation type="obsolete">Aktualisiere Wetterdaten...</translation>
    </message>
    <message>
        <source>Calm</source>
        <translation type="obsolete">Ruhig</translation>
    </message>
    <message>
        <source> at </source>
        <translation type="obsolete"> bei </translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation type="obsolete">Unbegrenzt</translation>
    </message>
    <message>
        <source> (minimal)</source>
        <translation type="obsolete"> (minimal)</translation>
    </message>
    <message>
        <source> (moderate)</source>
        <translation type="obsolete"> (gemäßigt)</translation>
    </message>
    <message>
        <source> (high)</source>
        <translation type="obsolete"> (hoch)</translation>
    </message>
    <message>
        <source> (extreme)</source>
        <translation type="obsolete"> (extrem)</translation>
    </message>
    <message>
        <source>Today a high of </source>
        <translation type="obsolete">Heute Höchstwerte um </translation>
    </message>
    <message>
        <source> and a low of </source>
        <translation type="obsolete">°C und Tiefstwerte um </translation>
    </message>
    <message>
        <source>. Currently there is a humidity of </source>
        <translation type="obsolete">°C. Momentan herrscht eine Luftfeuchtigkeit von </translation>
    </message>
    <message>
        <source>% and the winds are</source>
        <translation type="obsolete">% und der Wind </translation>
    </message>
    <message>
        <source> calm.</source>
        <translation type="obsolete">ist ruhig. </translation>
    </message>
    <message>
        <source> coming in at </source>
        <translation type="obsolete">weht mit </translation>
    </message>
    <message>
        <source> mph from the </source>
        <translation type="obsolete"> mph von </translation>
    </message>
    <message>
        <source> Km/h from the </source>
        <translation type="obsolete"> km/h von </translation>
    </message>
    <message>
        <source> Visibility will be unlimited for today.</source>
        <translation type="obsolete"> Die Sicht ist heute uneingeschränkt.</translation>
    </message>
    <message>
        <source> Visibility conditions are unknown.</source>
        <translation type="obsolete"> Sichtbedingungen sind unbekannt.</translation>
    </message>
    <message>
        <source> There will be a visibility of </source>
        <translation type="obsolete"> Die Sichtweite beträgt </translation>
    </message>
    <message>
        <source> miles.</source>
        <translation type="obsolete"> Meilen.</translation>
    </message>
    <message>
        <source> km.</source>
        <translation type="obsolete"> km.</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="obsolete">Sonntag</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="obsolete">Montag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="obsolete">Dienstag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="obsolete">Mittwoch</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="obsolete">Donnerstag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="obsolete">Freitag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="obsolete">Samstag</translation>
    </message>
    <message>
        <source>Date Error</source>
        <translation type="obsolete">Datumsfehler</translation>
    </message>
    <message>
        <source>Tomorrow expect a high of </source>
        <translation type="obsolete">Morgen: Höchstwerte um </translation>
    </message>
    <message>
        <source>Expected conditions: </source>
        <translation type="obsolete">Erwartete Lage: </translation>
    </message>
    <message>
        <source>Weather data from: </source>
        <translation type="obsolete">Wetterdaten vom: </translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation type="obsolete">Aktualisiere...</translation>
    </message>
    <message>
        <source> (Not All Information Available)</source>
        <translation type="obsolete"> (Nicht alle Informationen vorhanden)</translation>
    </message>
    <message>
        <source>*** Invalid Area ID or Server Error ***</source>
        <translation type="obsolete">*** Ungültige Orts-ID oder Server-Fehler ***</translation>
    </message>
    <message>
        <source>Imperial (Fahrenheit, in, etc)</source>
        <translation type="obsolete">Britisch (Fahrenheit, Inch, etc.)</translation>
    </message>
    <message>
        <source>Metric (Celsius, kPa, etc)</source>
        <translation type="obsolete">Metrisch (Celsius, kPa, etc.)</translation>
    </message>
    <message>
        <source> F</source>
        <translation type="obsolete">°F</translation>
    </message>
    <message>
        <source> C</source>
        <translation type="obsolete">°C</translation>
    </message>
    <message>
        <source>.</source>
        <translation type="obsolete">.</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Unbekannt</translation>
    </message>
    <message>
        <source> - PAUSED -</source>
        <translation type="obsolete"> - PAUSE -</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation type="obsolete">Dopplerradar</translation>
    </message>
    <message>
        <source>satellite image</source>
        <translation type="obsolete">Satellitenbild</translation>
    </message>
    <message>
        <source>Myth was unable to retrieve your weather data within the time allowed (%1 seconds).
Press OK to try again with a larger timeout value. Press Cancel to try again without animated radar maps.</source>
        <translation type="obsolete">Myth konnte die Wetterdaten nicht innerhalb der erlaubten Zeitspanne (%1 Sekunden) laden.
Drücken Sie &apos;Ok&apos; um es mit einem größeren Zeitfenster erneut zu versuchen. &apos;Abbrechen&apos; bewirkt das gleiche, jedoch ohne die Satellitenbilder zu laden.</translation>
    </message>
    <message>
        <source>Myth was unable to retrieve your weather data within the time allowed (%1 seconds).
Press OK to try again with a larger timeout value. Press Cancel to abort.</source>
        <translation type="obsolete">Myth konnte die Wetterdaten nicht innerhalb der erlaubten Zeitspanne (%1 Sekunden) laden.
Drücken Sie &apos;Ok&apos; um es mit einem größeren Zeitfenster erneut zu versuchen und &apos;Abbrechen&apos; um den Vorgang abzubrechen.</translation>
    </message>
    <message>
        <source>No Screens defined; Entering Screen Setup.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
